Documentation
¶
Overview ¶
Package cache provides thread-safe caching with TTL support.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsLikelyBot ¶
IsLikelyBot checks if a username suggests it's a bot based on common patterns.
Types ¶
type Cache ¶
type Cache struct {
// contains filtered or unexported fields
}
Cache provides thread-safe caching with TTL.
type Entry ¶
type Entry struct {
// contains filtered or unexported fields
}
Entry holds a cached value with expiration.
type UserCache ¶
type UserCache struct {
// contains filtered or unexported fields
}
UserCache caches user type information to avoid repeated API calls.
func (*UserCache) SetIfNotExists ¶
SetIfNotExists stores user info only if not already cached or if we have more definitive info.
Click to show internal directories.
Click to hide internal directories.